@@ -2,7 +2,7 @@
 # this repository contains the full copyright notices and license terms.
 
 try:
-    from trytond.modules.project_invoice.tests.test_project_invoice import suite
+    from trytond.modules.project_invoice.tests.test_project_invoice import suite  # noqa: E501
 except ImportError:
     from .test_project_invoice import suite
 
