@@ -1,25 +1,16 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
+from trytond.i18n import gettext
 from trytond.model import fields
+from trytond.model.exceptions import AccessError
 from trytond.pool import PoolMeta
 
 
-__all__ = ['TimesheetLine']
-
-
-class TimesheetLine(metaclass=PoolMeta):
+class Line(metaclass=PoolMeta):
     __name__ = 'timesheet.line'
     invoice_line = fields.Many2One('account.invoice.line', 'Invoice Line',
         readonly=True)
 
-    @classmethod
-    def __setup__(cls):
-        super(TimesheetLine, cls).__setup__()
-        cls._error_messages.update({
-                'modify_invoiced_line': 'You can not modify invoiced line.',
-                'delete_invoiced_line': 'You can not delete invoiced line.',
-                })
-
     @classmethod
     def copy(cls, records, default=None):
         if default is None:
@@ -27,7 +18,7 @@ class TimesheetLine(metaclass=PoolMeta):
         else:
             default = default.copy()
         default.setdefault('invoice_line', None)
-        return super(TimesheetLine, cls).copy(records, default=default)
+        return super().copy(records, default=default)
 
     @classmethod
     def write(cls, *args):
@@ -35,11 +26,13 @@ class TimesheetLine(metaclass=PoolMeta):
         for lines, values in zip(actions, actions):
             if (('duration' in values or 'work' in values)
                     and any(l.invoice_line for l in lines)):
-                cls.raise_user_error('modify_invoiced_line')
-        super(TimesheetLine, cls).write(*args)
+                raise AccessError(
+                    gettext('project_invoice.msg_modify_invoiced_line'))
+        super().write(*args)
 
     @classmethod
     def delete(cls, records):
         if any(r.invoice_line for r in records):
-            cls.raise_user_error('delete_invoiced_line')
-        super(TimesheetLine, cls).delete(records)
+            raise AccessError(
+                gettext('project_invoice.msg_delete_invoiced_line'))
+        super().delete(records)
